@@ -2,8 +2,50 @@
 
 #include <eel/eel-debug-drawing.h>
 
-static const char pixbuf_name[] = "/usr/share/pixmaps/gnome-globe.png";
-static const char tile_name[] = "/gnome/share/nautilus/patterns/camouflage.png";
+static const char pixbuf_name[] = DATADIR "/pixmaps/gnome-globe.png";
+static const char tile_name[] = DATADIR "/nautilus/patterns/camouflage.png";
+
+static GdkPixbuf *global_buffer = NULL;
+
+static void
+destroy_global_buffer (void)
+{
+	if (global_buffer != NULL) {
+		g_object_unref (global_buffer);
+		global_buffer = NULL;
+	}
+}
+
+static GdkPixbuf *
+get_global_buffer (int minimum_width, int minimum_height)
+{
+	static gboolean at_exit_deallocator_installed = FALSE;
+
+	g_return_val_if_fail (minimum_width > 0, NULL);
+	g_return_val_if_fail (minimum_height > 0, NULL);
+
+	if (global_buffer != NULL) {
+		if (gdk_pixbuf_get_width (global_buffer) >= minimum_width
+		    && gdk_pixbuf_get_height (global_buffer) >= minimum_height) {
+			return global_buffer;
+		}
+
+		destroy_global_buffer ();
+	}
+
+	g_assert (global_buffer == NULL);
+
+	global_buffer = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 
+					minimum_width, minimum_height);
+
+
+	if (at_exit_deallocator_installed == FALSE) {
+		at_exit_deallocator_installed = TRUE;
+		eel_debug_call_at_shutdown (destroy_global_buffer);
+	}
+
+	return global_buffer;
+}
 
 static int
 pixbuf_drawing_area_expose_event (GtkWidget *widget,
@@ -15,7 +57,8 @@ pixbuf_drawing_area_expose_event (GtkWidget *widget,
 	ArtIRect dest;
 	ArtIRect tile_area;
 
-	buffer = eel_gdk_pixbuf_get_global_buffer (widget->allocation.width, widget->allocation.height);
+	buffer = get_global_buffer (widget->allocation.width,
+				    widget->allocation.height);
 
 	if (tile == NULL) {
 		tile = gdk_pixbuf_new_from_file (tile_name, NULL);
